@@ -16,10 +16,7 @@
  #-------------------------------------------------------------------------------*/
 
 #include <cmath>
-#include <string>
 #include <vector>
-#include <iostream>
-#include "Eigen/Dense"
 #include "commons/utility.h"
 #include "commons/Data.h"
 #include "prediction/LocalLinearPredictionStrategy.h"
