@@ -27,7 +27,7 @@ public:
   bool relabel(
       const std::vector<size_t>& samples,
       const Data& data,
-      std::vector<double>& responses_by_sample) const;
+      Eigen::ArrayXXd& responses_by_sample) const;
 };
 
 } // namespace grf
